==> Newsletter-1.0.0.zip: lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Newsletters';
$lang['moddescription'] = 'Allows you to create a mailing list to CMS users and the users of the FEU module';
$lang['postinstall'] = 'Newsletter module successfully installed!';
$lang['postuninstall'] = 'Newsletter module successfully uninstalled!';
$lang['uninstallconfirm'] = 'Are you sure, you want to remove Newsletter module?';
$lang['installed'] = 'Module "Newsletter" - version %s installed.';
$lang['uninstalled'] = 'Module "Newsletter" uninstalled.';
$lang['help'] = file_get_contents(dirname(__FILE__).'/../help/en_US.hlp');

#Module texts
$lang['Mailings'] = 'Mailings';
$lang['EmailTemplates'] = 'E-mail templates';
$lang['FEUSettings'] = 'FEU module settings';
$lang['LastMailingDate'] = 'Date of last mailing';
$lang['SenderEmail'] = 'E-mail of the sender';
$lang['Subject'] = 'Subject';
$lang['HTMLTemplate'] = 'HTML template';
$lang['TXTTemplate'] = 'Text(alternative) template';
$lang['TemplateAllowedTagsText'] = 'Allowed tags in template content';
$lang['EmailText'] = 'Email text';
$lang['SetActive'] = 'Set active';
$lang['SetInactive'] = 'Set inactive';
$lang['AddMailing'] = 'Create new mailing';
$lang['HTMLContent'] = 'HTML content';
$lang['TXTContent'] = 'Text(alternative) content';
$lang['NoTemplate'] = 'Without template';
$lang['SendMails'] = 'Send mails';
$lang['CMSUsers'] = 'CMS users';
$lang['FrontendUsers'] = 'Frontend users';
$lang['TotalToSend'] = 'Total to send';
$lang['Sent'] = 'Sent';
$lang['ErrorSending'] = 'Error sending';
$lang['ErrorsWhileSending'] = 'Some mails could not be sent';
$lang['SendingMessage'] = 'Please do not close this window until the process is completed';
$lang['Done'] = 'Done';
$lang['FEUModuleEmailField'] = 'User E-mail';
$lang['FEUModuleNoProperty'] = 'Not used';
$lang['FEUModuleNoEmailProperty'] = 'Login field';
$lang['FEUModuleFirstNameField'] = 'First name in {USERNAME} tag';
$lang['FEUModuleLastNameField'] = 'Last name in {USERNAME} tag';

#Module errors texts
$lang['ErrTemplateNameEmpty'] = 'The field "Name" can not be empty!';
$lang['ErrMailingNameEmpty'] = 'The field "Name" can not be empty!';
$lang['ErrSenderEmailEmpty'] = 'The field "E-mail of the sender" can not be empty!';
$lang['ErrSubjectEmpty'] = 'The field "Subject" can not be empty!';

#Module event logs
$lang['EventLogMailingRemoved'] = 'Mailing removed.';
$lang['EventLogTemplateRemoved'] = 'Template removed.';
$lang['EventLogMailingSaved'] = 'Mailing saved.';
$lang['EventLogTemplateSaved'] = 'Template saved.';
$lang['EventLogFEUSettingsSaved'] = 'FEU settings saved.';
$lang['EventLogMailingCommited'] = 'Mailing commited.';
?>

==> Newsletter-1.1.0.zip: lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Newsletters';
$lang['moddescription'] = 'Allows you to create a mailing list to CMS users and the users of the FEU module';
$lang['postinstall'] = 'Newsletter module successfully installed!';
$lang['postuninstall'] = 'Newsletter module successfully uninstalled!';
$lang['uninstallconfirm'] = 'Are you sure, you want to remove Newsletter module?';
$lang['installed'] = 'Module "Newsletter" - version %s installed.';
$lang['uninstalled'] = 'Module "Newsletter" uninstalled.';
$lang['help'] = file_get_contents(dirname(__FILE__).'/../help/en_US.hlp');

#Module texts
$lang['Mailings'] = 'Mailings';
$lang['EmailTemplates'] = 'E-mail templates';
$lang['FEUSettings'] = 'FEU module settings';
$lang['LastMailingDate'] = 'Date of last mailing';
$lang['SenderEmail'] = 'E-mail of the sender';
$lang['Subject'] = 'Subject';
$lang['HTMLTemplate'] = 'HTML template';
$lang['TXTTemplate'] = 'Text(alternative) template';
$lang['TemplateAllowedTagsText'] = 'Allowed tags in template content';
$lang['EmailText'] = 'Email text';
$lang['SetActive'] = 'Set active';
$lang['SetInactive'] = 'Set inactive';
$lang['AddMailing'] = 'Create new mailing';
$lang['HTMLContent'] = 'HTML content';
$lang['TXTContent'] = 'Text(alternative) content';
$lang['NoTemplate'] = 'Without template';
$lang['SendMails'] = 'Send mails';
$lang['CMSUsers'] = 'CMS users';
$lang['FrontendUsers'] = 'Frontend users';
$lang['TotalToSend'] = 'Total to send';
$lang['Sent'] = 'Sent';
$lang['ErrorSending'] = 'Error sending';
$lang['ErrorsWhileSending'] = 'Some mails could not be sent';
$lang['SendingMessage'] = 'Please do not close this window until the process is completed';
$lang['Done'] = 'Done';
$lang['FEUModuleEmailField'] = 'User E-mail';
$lang['FEUModuleNoProperty'] = 'Not used';
$lang['FEUModuleNoEmailProperty'] = 'Login field';
$lang['FEUModuleFirstNameField'] = 'First name in {USERNAME} tag';
$lang['FEUModuleLastNameField'] = 'Last name in {USERNAME} tag';
$lang['NoPermissions'] = 'Unfortunately you do not have the required permissions to view this module. Contact to CMS administrator.';

#Module errors texts
$lang['ErrTemplateNameEmpty'] = 'The field "Name" can not be empty!';
$lang['ErrMailingNameEmpty'] = 'The field "Name" can not be empty!';
$lang['ErrSenderEmailEmpty'] = 'The field "E-mail of the sender" can not be empty!';
$lang['ErrSubjectEmpty'] = 'The field "Subject" can not be empty!';

#Module premissions
$lang['PermissionsShowModule'] = 'Module "Newsletter": Show module';
$lang['PermissionsViewMailings'] = 'Module "Newsletter": View mailings';
$lang['PermissionsCreateMailings'] = 'Module "Newsletter": Create mailings';
$lang['PermissionsDeleteMailings'] = 'Module "Newsletter": Delete mailings';
$lang['PermissionsProcessMailings'] = 'Module "Newsletter": Send emails';
$lang['PermissionsViewTempltes'] = 'Module "Newsletter": View templates';
$lang['PermissionsCreateTemplates'] = 'Module "Newsletter": Create templates';
$lang['PermissionsDeleteTemplates'] = 'Module "Newsletter": Delete templates';
$lang['PermissionsChangeModuleSettings'] = 'Module "Newsletter": Change module settings';

#Module event logs
$lang['EventLogMailingRemoved'] = 'Mailing removed.';
$lang['EventLogTemplateRemoved'] = 'Template removed.';
$lang['EventLogMailingSaved'] = 'Mailing saved.';
$lang['EventLogTemplateSaved'] = 'Template saved.';
$lang['EventLogFEUSettingsSaved'] = 'FEU settings saved.';
$lang['EventLogMailingCommited'] = 'Mailing commited.';
?>
